==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/BLANKETORDERUSERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BLANKETORDERUSERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BLANKETORDERUSERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BLANKETORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BLANKETORDERUSERID_Type", propOrder = {
    "blanketorderid",
    "userid"
})
public class BLANKETORDERUSERID_Type {

    @XmlElement(name = "BLANKETORDERID", required = true)
    protected BLANKETORDERID_Type blanketorderid;
    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;

    /**
     * Obtient la valeur de la propriété blanketorderid.
     * 
     * @return
     *     possible object is
     *     {@link BLANKETORDERID_Type }
     *     
     */
    public BLANKETORDERID_Type getBLANKETORDERID() {
        return blanketorderid;
    }

    /**
     * Définit la valeur de la propriété blanketorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link BLANKETORDERID_Type }
     *     
     */
    public void setBLANKETORDERID(BLANKETORDERID_Type value) {
        this.blanketorderid = value;
    }

    /**
     * Obtient la valeur de la propriété userid.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Définit la valeur de la propriété userid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/BLANKETORDERUSERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BLANKETORDERUSERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BLANKETORDERUSERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BLANKETORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BLANKETORDERUSERID_Type", propOrder = {
    "blanketorderid",
    "userid"
})
public class BLANKETORDERUSERID_Type {

    @XmlElement(name = "BLANKETORDERID", required = true)
    protected BLANKETORDERID_Type blanketorderid;
    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;

    /**
     * Gets the value of the blanketorderid property.
     * 
     * @return
     *     possible object is
     *     {@link BLANKETORDERID_Type }
     *     
     */
    public BLANKETORDERID_Type getBLANKETORDERID() {
        return blanketorderid;
    }

    /**
     * Sets the value of the blanketorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link BLANKETORDERID_Type }
     *     
     */
    public void setBLANKETORDERID(BLANKETORDERID_Type value) {
        this.blanketorderid = value;
    }

    /**
     * Gets the value of the userid property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Sets the value of the userid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

}
